==> haskell-primitive-0.6.1.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: primitive
version: 0.6.1.0
id: primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
key: primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
license: BSD3
copyright: (c) Roman Leshchinskiy 2009-2012
maintainer: libraries@haskell.org
homepage: https://github.com/haskell/primitive
synopsis: Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.
category: Data
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
exposed: True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.MachDeps
    Data.Primitive.Types Data.Primitive.Array Data.Primitive.ByteArray
    Data.Primitive.Addr Data.Primitive.MutVar
hidden-modules: Data.Primitive.Internal.Compat
                Data.Primitive.Internal.Operations
abi: e10bc00637fd0c8a1404bd3c1b8e07a9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/primitive-0.6.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/primitive-0.6.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/primitive-0.6.1.0
hs-libraries: HSprimitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
include-dirs: /usr/lib/ghc-8.0.1/site-local/primitive-0.6.1.0/include
includes:
    primitive-memops.h
depends:
    base-4.9.0.0 ghc-prim-0.5.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html: /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-0.6.2.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: primitive
version: 0.6.2.0
id: primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ
key: primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ
license: BSD3
copyright: (c) Roman Leshchinskiy 2009-2012
maintainer: libraries@haskell.org
homepage: https://github.com/haskell/primitive
synopsis: Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.
category: Data
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
exposed: True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.MachDeps
    Data.Primitive.Types Data.Primitive.Array Data.Primitive.ByteArray
    Data.Primitive.SmallArray Data.Primitive.UnliftedArray
    Data.Primitive.Addr Data.Primitive.MutVar
hidden-modules: Data.Primitive.Internal.Compat
                Data.Primitive.Internal.Operations
abi: 4bf29d1d5c5844f62346475600841675
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/primitive-0.6.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/primitive-0.6.2.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/primitive-0.6.2.0
hs-libraries: HSprimitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ
include-dirs: /usr/lib/ghc-8.0.1/site-local/primitive-0.6.2.0/include
includes:
    primitive-memops.h
depends:
    base-4.9.0.0 ghc-prim-0.5.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html: /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
